@@ -3,8 +3,8 @@ package gui
 import (
 	"fmt"
 
+	"github.com/danvergara/gocui"
 	"github.com/fatih/color"
-	"github.com/jroimartin/gocui"
 	"github.com/olekukonko/tablewriter"
 )
 
@@ -64,7 +64,7 @@ func (gui *Gui) inputQuery() func(g *gocui.Gui, v *gocui.View) error {
 	}
 }
 
-// selectTable perfoms a select statement based on the selected table.
+// selectTable performs a select statement based on the selected table.
 func (gui *Gui) selectTable(g *gocui.Gui, v *gocui.View) error {
 	v.Rewind()
 
@@ -96,3 +96,47 @@ func (gui *Gui) selectTable(g *gocui.Gui, v *gocui.View) error {
 
 	return nil
 }
+
+func (gui *Gui) renderStructure(g *gocui.Gui, v *gocui.View) error {
+	v.Rewind()
+
+	_, cy := v.Cursor()
+
+	t, err := v.Line(cy)
+	if err != nil {
+		return err
+	}
+
+	resultSet, columnNames, err := gui.c.TableStructure(t)
+	if err != nil {
+		return err
+	}
+
+	ov, err := gui.g.View("structure")
+	if err != nil {
+		return err
+	}
+
+	// Cleans the view.
+	ov.Clear()
+
+	if err := ov.SetCursor(0, 0); err != nil {
+		return err
+	}
+
+	renderTable(ov, columnNames, resultSet)
+
+	return nil
+}
+
+// metadata get the metadata from a given table name.
+func (gui *Gui) metadata(g *gocui.Gui, v *gocui.View) error {
+	if err := gui.selectTable(g, v); err != nil {
+		return err
+	}
+
+	if err := gui.renderStructure(g, v); err != nil {
+		return err
+	}
+	return nil
+}
