@@ -1,8 +1,10 @@
 package gui
 
 import (
+	"errors"
+
 	"github.com/danvergara/dblab/pkg/client"
-	"github.com/jroimartin/gocui"
+	"github.com/danvergara/gocui"
 )
 
 // Gui wraps the gocui Gui object which handles rendering and events.
@@ -25,6 +27,7 @@ func (gui *Gui) Run() error {
 
 	gui.g.Highlight = true
 	gui.g.Cursor = true
+	gui.g.Mouse = true
 	gui.g.SelFgColor = gocui.ColorGreen
 
 	gui.g.SetManagerFunc(gui.layout)
@@ -33,7 +36,7 @@ func (gui *Gui) Run() error {
 		return err
 	}
 
-	if err := gui.g.MainLoop(); err != nil && err != gocui.ErrQuit {
+	if err := gui.g.MainLoop(); err != nil && !errors.Is(err, gocui.ErrQuit) {
 		return err
 	}
 
