@@ -1,7 +1,7 @@
 package gui
 
 import (
-	"github.com/jroimartin/gocui"
+	"github.com/danvergara/gocui"
 )
 
 func (gui *Gui) keybindings() error {
@@ -14,7 +14,7 @@ func (gui *Gui) keybindings() error {
 		return err
 	}
 
-	if err := gui.g.SetKeybinding("query", gocui.KeyCtrlJ, gocui.ModNone, nextView("query", "rows")); err != nil {
+	if err := gui.g.SetKeybinding("query", gocui.KeyCtrlJ, gocui.ModNone, moveDown); err != nil {
 		return err
 	}
 
@@ -22,17 +22,29 @@ func (gui *Gui) keybindings() error {
 		return err
 	}
 
+	if err := gui.g.SetKeybinding("rows", gocui.KeyCtrlH, gocui.ModNone, nextView("rows", "tables")); err != nil {
+		return err
+	}
+
+	if err := gui.g.SetKeybinding("structure", gocui.KeyCtrlH, gocui.ModNone, nextView("structure", "tables")); err != nil {
+		return err
+	}
+
+	if err := gui.g.SetKeybinding("structure", gocui.KeyCtrlK, gocui.ModNone, nextView("structure", "query")); err != nil {
+		return err
+	}
+
 	// SQL helpers
 	if err := gui.g.SetKeybinding("query", gocui.KeyCtrlSpace, gocui.ModNone, gui.inputQuery()); err != nil {
 		return err
 	}
 
-	if err := gui.g.SetKeybinding("tables", gocui.KeyEnter, gocui.ModNone, gui.selectTable); err != nil {
+	if err := gui.g.SetKeybinding("tables", gocui.KeyEnter, gocui.ModNone, gui.metadata); err != nil {
 		return err
 	}
 
 	// navigation directives for the tables panel.
-	if err := gui.g.SetKeybinding("tables", gocui.KeyCtrlK, gocui.ModNone, cursorUp); err != nil {
+	if err := gui.g.SetKeybinding("tables", 'k', gocui.ModNone, cursorUp); err != nil {
 		return err
 	}
 
@@ -40,7 +52,7 @@ func (gui *Gui) keybindings() error {
 		return err
 	}
 
-	if err := gui.g.SetKeybinding("tables", gocui.KeyCtrlJ, gocui.ModNone, cursorDown); err != nil {
+	if err := gui.g.SetKeybinding("tables", 'j', gocui.ModNone, cursorDown); err != nil {
 		return err
 	}
 
@@ -53,18 +65,42 @@ func (gui *Gui) keybindings() error {
 		return err
 	}
 
+	if err := gui.g.SetKeybinding("rows", 'k', gocui.ModNone, cursorUp); err != nil {
+		return err
+	}
+
 	if err := gui.g.SetKeybinding("rows", gocui.KeyArrowDown, gocui.ModNone, cursorDown); err != nil {
 		return err
 	}
 
+	if err := gui.g.SetKeybinding("rows", 'j', gocui.ModNone, cursorDown); err != nil {
+		return err
+	}
+
 	if err := gui.g.SetKeybinding("rows", gocui.KeyArrowRight, gocui.ModNone, cursorRight); err != nil {
 		return err
 	}
 
+	if err := gui.g.SetKeybinding("rows", 'l', gocui.ModNone, cursorRight); err != nil {
+		return err
+	}
+
 	if err := gui.g.SetKeybinding("rows", gocui.KeyArrowLeft, gocui.ModNone, cursorLeft); err != nil {
 		return err
 	}
 
+	if err := gui.g.SetKeybinding("rows", 'h', gocui.ModNone, cursorLeft); err != nil {
+		return err
+	}
+
+	if err := gui.g.SetKeybinding("structure", gocui.KeyCtrlS, gocui.ModNone, setViewOnTop); err != nil {
+		return err
+	}
+
+	if err := gui.g.SetKeybinding("rows", gocui.KeyCtrlS, gocui.ModNone, setViewOnTop); err != nil {
+		return err
+	}
+
 	// quit function event.
 	if err := gui.g.SetKeybinding("", gocui.KeyCtrlC, gocui.ModNone, quit); err != nil {
 		return err
